==> rc-ui-lib-0.1.41.tgz: package/es/list/List.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useRef, forwardRef, useImperativeHandle, isValidElement, useContext } from 'react';
import classnames from 'classnames';
import Loading from '../loading';
import { getRect } from '../hooks/use-rect';
import useScrollParent from '../hooks/use-scroll-parent';
import useEventListener from '../hooks/use-event-listener';
import { isHidden } from '../utils';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var List = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('list', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useSetState = useSetState({
    loading: props.loading,
    error: props.error
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var root = useRef();
  var scrollParent = useRef(null);
  var placeholder = useRef();
  scrollParent.current = useScrollParent(root); // 判断是否需要加载

  var check = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var offset, direction, scrollParentRect, isReachEdge, placeholderRect;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (props.onLoad) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              if (!(state.loading || props.finished || state.error)) {
                _context.next = 4;
                break;
              }

              return _context.abrupt("return");

            case 4:
              offset = props.offset, direction = props.direction;
              scrollParentRect = getRect(scrollParent.current);

              if (!(!scrollParentRect.height || isHidden(root.current))) {
                _context.next = 8;
                break;
              }

              return _context.abrupt("return");

            case 8:
              isReachEdge = false;
              placeholderRect = getRect(placeholder.current);

              if (direction === 'up') {
                isReachEdge = scrollParentRect.top - placeholderRect.top <= offset;
              } else {
                isReachEdge = placeholderRect.bottom - scrollParentRect.bottom <= offset;
              }

              if (!isReachEdge) {
                _context.next = 24;
                break;
              }

              _context.prev = 12;
              updateState({
                loading: true
              });

              if (!props.onLoad) {
                _context.next = 17;
                break;
              }

              _context.next = 17;
              return props.onLoad();

            case 17:
              updateState({
                loading: false
              });
              _context.next = 24;
              break;

            case 20:
              _context.prev = 20;
              _context.t0 = _context["catch"](12);
              // eslint-disable-next-line no-console
              console.warn('onLoad error:', _context.t0);
              updateState({
                loading: false,
                error: true
              });

            case 24:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[12, 20]]);
    }));

    return function check() {
      return _ref.apply(this, arguments);
    };
  }();

  var renderFinishedText = function renderFinishedText() {
    if (props.finished && props.finishedText) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('finished-text'))
      }, props.finishedText);
    }

    return null;
  };

  var clickErrorText = function clickErrorText() {
    updateState({
      error: false
    });
    check();
  };

  var renderErrorText = function renderErrorText() {
    if (state.error && props.errorText) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('error-text')),
        onClick: clickErrorText
      }, props.errorText);
    }

    return null;
  };

  var renderLoading = function renderLoading() {
    if (state.loading && !props.finished) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('loading'))
      }, /*#__PURE__*/isValidElement(props.loadingText) ? props.loadingText : /*#__PURE__*/React.createElement(Loading, {
        className: classnames(bem('loading-icon')),
        size: 16
      }, props.loadingText));
    }

    return null;
  };

  useUpdateEffect(function () {
    if (props.autoCheck) {
      check();
    }
  }, [state.loading, props.finished, props.error]);
  useUpdateEffect(function () {
    updateState({
      loading: props.loading,
      error: props.error
    });
  }, [props.loading, props.error]);
  useUpdateEffect(function () {
    if (scrollParent.current && props.immediateCheck) {
      check();
    }
  }, [scrollParent.current]);
  useEventListener('scroll', check, {
    target: scrollParent.current,
    depends: [state.loading, props.finished, state.error]
  });
  useImperativeHandle(ref, function () {
    return {
      check: check,
      state: state
    };
  });
  var Placeholder = /*#__PURE__*/React.createElement("div", {
    ref: placeholder,
    className: classnames(bem('placeholder'))
  });
  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    role: "feed",
    className: classnames(bem()),
    "aria-busy": state.loading
  }, props.direction === 'down' ? props.children : Placeholder, renderLoading(), renderFinishedText(), renderErrorText(), props.direction === 'up' ? props.children : Placeholder);
});
List.defaultProps = {
  offset: 300,
  direction: 'down',
  immediateCheck: true,
  autoCheck: true,
  loadingText: '加载中...',
  finishedText: '没有更多了'
};
export default List;

==> rc-ui-lib-1.0.0.tgz: package/es/list/List.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useRef, forwardRef, useImperativeHandle, isValidElement, useContext } from 'react';
import classnames from 'classnames';
import Loading from '../loading';
import { getRect } from '../hooks/use-rect';
import useScrollParent from '../hooks/use-scroll-parent';
import useEventListener from '../hooks/use-event-listener';
import { isHidden } from '../utils';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var List = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('list', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useSetState = useSetState({
    loading: props.loading,
    error: props.error
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      updateState = _useSetState2[1];

  var errorRecent = useRef(props.error);
  var root = useRef();
  var scrollParent = useRef(null);
  var placeholder = useRef();
  scrollParent.current = useScrollParent(root); // 判断是否需要加载

  var check = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var offset, direction, scrollParentRect, isReachEdge, placeholderRect;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (props.onLoad) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              if (!(state.loading || props.finished || errorRecent.current)) {
                _context.next = 4;
                break;
              }

              return _context.abrupt("return");

            case 4:
              offset = props.offset, direction = props.direction;
              scrollParentRect = getRect(scrollParent.current);

              if (!(!scrollParentRect.height || isHidden(root.current))) {
                _context.next = 8;
                break;
              }

              return _context.abrupt("return");

            case 8:
              isReachEdge = false;
              placeholderRect = getRect(placeholder.current);

              if (direction === 'up') {
                isReachEdge = scrollParentRect.top - placeholderRect.top <= offset;
              } else {
                isReachEdge = placeholderRect.bottom - scrollParentRect.bottom <= offset;
              }

              if (!isReachEdge) {
                _context.next = 25;
                break;
              }

              _context.prev = 12;
              updateState({
                loading: true
              });

              if (!props.onLoad) {
                _context.next = 17;
                break;
              }

              _context.next = 17;
              return props.onLoad();

            case 17:
              updateState({
                loading: false
              });
              _context.next = 25;
              break;

            case 20:
              _context.prev = 20;
              _context.t0 = _context["catch"](12);
              // eslint-disable-next-line no-console
              console.warn('onLoad error:', _context.t0);
              updateState({
                loading: false,
                error: true
              });
              errorRecent.current = true;

            case 25:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[12, 20]]);
    }));

    return function check() {
      return _ref.apply(this, arguments);
    };
  }();

  var renderFinishedText = function renderFinishedText() {
    if (props.finished && props.finishedText) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('finished-text'))
      }, props.finishedText);
    }

    return null;
  };

  var clickErrorText = function clickErrorText() {
    updateState({
      error: false
    });
    errorRecent.current = false;
    check();
  };

  var renderErrorText = function renderErrorText() {
    if (state.error && props.errorText) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('error-text')),
        onClick: clickErrorText
      }, props.errorText);
    }

    return null;
  };

  var renderLoading = function renderLoading() {
    if (state.loading && !props.finished) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('loading'))
      }, /*#__PURE__*/isValidElement(props.loadingText) ? props.loadingText : /*#__PURE__*/React.createElement(Loading, {
        className: classnames(bem('loading-icon')),
        size: 16
      }, props.loadingText));
    }

    return null;
  };

  useUpdateEffect(function () {
    if (props.autoCheck) {
      check();
    }
  }, [state.loading, props.finished, props.error]);
  useUpdateEffect(function () {
    updateState({
      loading: props.loading,
      error: props.error
    });
    errorRecent.current = props.error;
  }, [props.loading, props.error]);
  useUpdateEffect(function () {
    if (scrollParent.current && props.immediateCheck) {
      check();
    }
  }, [scrollParent.current]);
  useEventListener('scroll', check, {
    target: scrollParent.current,
    depends: [state.loading, props.finished, state.error]
  });
  useImperativeHandle(ref, function () {
    return {
      check: check,
      state: state
    };
  });
  var Placeholder = /*#__PURE__*/React.createElement("div", {
    ref: placeholder,
    className: classnames(bem('placeholder'))
  });
  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    role: "feed",
    className: classnames(bem()),
    "aria-busy": state.loading
  }, props.direction === 'down' ? props.children : Placeholder, renderLoading(), renderFinishedText(), renderErrorText(), props.direction === 'up' ? props.children : Placeholder);
});
List.defaultProps = {
  offset: 300,
  direction: 'down',
  immediateCheck: true,
  autoCheck: true,
  loadingText: '加载中...',
  finishedText: '没有更多了'
};
export default List;
